
# This file was automatically generated by Dist::Zilla::Plugin::Alien v0.023.
use strict;
use warnings;

use Module::Build 0.28;
use lib qw{inc}; use Alien::Base::ModuleBuild;

my %module_build_args = (
  "alien_bin_requires" => {
    "Alien::patch" => "0.06"
  },
  "alien_build_commands" => [
    "%{patch} -p1 < ../../patches/yaml-0_1_6.diff",
    "%c --prefix=%s"
  ],
  "alien_inline_auto_include" => [],
  "alien_install_commands" => [
    "make install"
  ],
  "alien_isolate_dynamic" => 1,
  "alien_name" => "yaml-0.1",
  "alien_repository" => {
    "host" => "pyyaml.org",
    "location" => "/download/libyaml/",
    "pattern" => "^yaml-.*\\.tar\\.gz\$",
    "protocol" => "http"
  },
  "alien_stage_install" => 1,
  "configure_requires" => {
    "Alien::Base::ModuleBuild" => "0.020",
    "File::ShareDir" => "1.03",
    "perl" => "5.008001"
  },
  "dist_abstract" => "Build and install libyaml, a C-based YAML parser and emitter",
  "dist_author" => [
    "Richard Sim\x{f5}es <rsimoes AT cpan DOT org>"
  ],
  "dist_name" => "Alien-LibYAML",
  "dist_version" => "v0.1.10",
  "license" => "mit",
  "module_name" => "Alien::LibYAML",
  "recursive_test_files" => 1,
  "requires" => {
    "Alien::Base" => "0.020",
    "File::ShareDir" => "1.03",
    "perl" => "5.008001"
  },
  "test_requires" => {
    "Test::More" => 0,
    "perl" => "5.008001"
  }
);


my %fallback_build_requires = (
  "Test::More" => 0,
  "perl" => "5.008001"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Alien::Base::ModuleBuild->new(%module_build_args);


$build->create_build_script;
